﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Text;
using Telerik.Windows.Controls.Map;

namespace FileSystemMapProvider
{
	/// <summary>
	/// Tile source which read map tiles from the file system.
	/// </summary>
	public class FileSystemTileSource : TiledMapSource
	{
		private string tilePathFormat;

		/// <summary>
		/// Initializes a new instance of the FileSystemTileSource class.
		/// </summary>
		/// <param name="tilePathFormat">Format string to access tiles in file system.</param>
		public FileSystemTileSource(string tilePathFormat)
			: base(1, 20, 256, 256)
		{
			this.tilePathFormat = tilePathFormat;
		}

		/// <summary>
		/// Initialize provider.
		/// </summary>
		public override void Initialize()
		{
			// Raise provider intialized event.
			this.RaiseIntializeCompleted();
		}

		/// <summary>
		/// Gets the image URI.
		/// </summary>
		/// <param name="tileLevel">Tile level.</param>
		/// <param name="tilePositionX">Tile X.</param>
		/// <param name="tilePositionY">Tile Y.</param>
		/// <returns>URI of image.</returns>
		protected override Uri GetTile(int tileLevel, int tilePositionX, int tilePositionY)
		{
			int zoomLevel = ConvertTileToZoomLevel(tileLevel);

			string tileFileName = this.tilePathFormat.Replace("{zoom}", zoomLevel.ToString(CultureInfo.InvariantCulture));
			tileFileName = tileFileName.Replace("{x}", tilePositionX.ToString(CultureInfo.InvariantCulture));
			tileFileName = tileFileName.Replace("{y}", tilePositionY.ToString(CultureInfo.InvariantCulture));

			if (File.Exists(tileFileName))
			{
				return new Uri(tileFileName);
			}
			else
			{
				return null;
			}
		}
	}
}
